@@ -1,5 +1,5 @@
 # -*- coding:utf-8 -*-
 "Yet Another DI Container"
 
-from container import Injectable, Container
+from yadic.container import Injectable, Container
 
